@@ -10,10 +10,10 @@ from nos_parser.persistence_handler import PersistenceHandler
 
 
 class GCSPersistence(PersistenceHandler):
-    def __init__(self, blob_path, bucket_path):
+    def __init__(self):
         self.client = storage.Client()
-        self.blob_path = blob_path
-        self.bucket_path = bucket_path
+        self.blob_path = 'drain_state.bin'
+        self.bucket_path = 'tel_nos_persistent'
         self.bucket=self.client.get_bucket(self.bucket_path);  
         
         
